@@ -1,7 +1,5 @@
 /*
-  Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-  2006, 2007, 2008, 2009, 2010, 2011, 2012 Free Software Foundation,
-  Inc.
+  Copyright (C) 1997-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
